@@ -8,33 +8,33 @@
 # THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 import os
-from typing import List
+from typing import List, Optional
 
 
 def check_directory(path: str) -> bool:
     return os.path.exists(os.path.join(path, ".k8t"))
 
 
-def get_base_dir(root: str, cluster: str, environment: str) -> str:
+def get_base_dir(root: str, cluster: Optional[str], environment: Optional[str]) -> str:
     base_path = root
 
     if cluster is not None:
         base_path = os.path.join(base_path, "clusters", cluster)
 
         if not os.path.isdir(base_path):
-            raise RuntimeError("No such cluster: {}".format(cluster))
+            raise RuntimeError(f"No such cluster: {cluster}")
 
     if environment is not None:
         base_path = os.path.join(base_path, "environments", environment)
 
         if not os.path.isdir(base_path):
-            raise RuntimeError("No such environment: {}".format(environment))
+            raise RuntimeError(f"No such environment: {environment}")
 
     return base_path
 
 
 # pylint: disable=too-many-arguments
-def find_files(root: str, cluster: str, environment: str, name: str, file_ok=True, dir_ok=True) -> List[str]:
+def find_files(root: str, cluster: Optional[str], environment: Optional[str], name: str, file_ok=True, dir_ok=True) -> List[str]:
     def check(path):
         return (file_ok and os.path.isfile(path)) or (dir_ok and os.path.isdir(root_path))
 
@@ -58,7 +58,7 @@ def find_files(root: str, cluster: str, environment: str, name: str, file_ok=Tru
         cluster_path = os.path.join(root, "clusters", cluster)
 
         if not os.path.isdir(cluster_path):
-            raise RuntimeError("no such cluster: {}".format(cluster))
+            raise RuntimeError(f"no such cluster: {cluster}")
 
         file_path = os.path.join(cluster_path, name)
 
@@ -74,6 +74,6 @@ def find_files(root: str, cluster: str, environment: str, name: str, file_ok=Tru
                 env_found = True
 
     if not env_found:
-        raise RuntimeError("no such environment: {}".format(environment))
+        raise RuntimeError(f"no such environment: {environment}")
 
     return files
